@@ -68,7 +68,7 @@ see.gam.tck<-function ()
 
 
 see.gamcdf.tck<-function (){ 
-  old.par <- par(no.readonly = TRUE)
+#  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
@@ -133,6 +133,6 @@ see.gamcdf.tck<-function (){
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-    on.exit(par(old.par))
+ #   on.exit(par(old.par))
   }  
                             
\ No newline at end of file
